package com.outbrain.catalog.ListLayouts;

import android.os.Bundle;
import android.view.View;
import android.widget.ImageView;
import android.widget.ListView;

import androidx.appcompat.app.AppCompatActivity;

import com.outbrain.OBSDK.Entities.OBRecommendation;
import com.outbrain.OBSDK.Entities.OBRecommendationsResponse;
import com.outbrain.OBSDK.FetchRecommendations.OBRequest;
import com.outbrain.OBSDK.FetchRecommendations.RecommendationsListener;
import com.outbrain.OBSDK.Outbrain;
import com.outbrain.catalog.R;
import com.outbrain.catalog.Utils.CatalogUtils;

public class ClassicWithoutImageActivity extends AppCompatActivity implements RecommendationsListener {
    ListView listView;

    public void onCreate(Bundle savedBundle) {
        super.onCreate(savedBundle);
        setContentView(R.layout.outbrain_single_list_view_activity);

        listView = findViewById(R.id.outbrain_main_list_view);
        listView.setDivider(null);
        listView.setDividerHeight(0);
        View headerView = getLayoutInflater().inflate(R.layout.outbrain_classic_recommendation_list_header, null);
        listView.addHeaderView(headerView);
        ImageView whatIsWrapper = headerView.findViewById(R.id.recommended_by_image);
        whatIsWrapper.setOnClickListener(view -> launchWhatIs());

        fetchForRecommendations();
    }

    private void launchWhatIs() {
        String aboutOutbrainUrl = Outbrain.getOutbrainAboutURL(this);
        CatalogUtils.openURLInBrowser(aboutOutbrainUrl, this);
    }

    private void fetchForRecommendations() {
        OBRequest request = new OBRequest();
        request.setWidgetId("SDK_2");
        request.setUrl(getString(R.string.outbrain_sample_url));
        Outbrain.fetchRecommendations(request, this);
    }

    @Override
    public void onOutbrainRecommendationsSuccess(final OBRecommendationsResponse recommendations) {
        assignAdapter(recommendations);
    }

    @Override
    public void onOutbrainRecommendationsFailure(Exception ex) {
        ex.printStackTrace();
    }

    private void assignAdapter(final OBRecommendationsResponse recommendations) {
        OutbrainSingleItemLayoutAdapter adapter = new OutbrainSingleItemLayoutAdapter(this, R.layout.classic_without_image, recommendations.getAll());
        listView.setAdapter(adapter);
        listView.setOnItemClickListener((adapterView, view, i, l) -> {
            try {
                openRecommendationInBrowser(recommendations.get(i - 1));
            } catch (Exception ignored) {
            }
        });
    }

    private void openRecommendationInBrowser(OBRecommendation obRecommendation) {
        CatalogUtils.openURLInBrowser(Outbrain.getUrl(obRecommendation), this);
    }
}


