package com.outbrain.catalog;

import android.content.Intent;
import android.os.Bundle;
import android.util.Pair;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ListView;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import com.outbrain.catalog.GridLayouts.GridWithImagesActivity;
import com.outbrain.catalog.ListLayouts.ClassicWithImageActivity;
import com.outbrain.catalog.ListLayouts.ClassicWithoutImageActivity;
import com.outbrain.catalog.SFWebView.SFWebViewRecyclerViewActivity;
import com.outbrain.catalog.SFWebView.SFWebViewScrollViewActivity;

import java.util.ArrayList;


public class MainActivity extends AppCompatActivity {


    @Override
    public void onCreate(Bundle savedBundle) {
        super.onCreate(savedBundle);
        setContentView(R.layout.outbrain_single_list_view_activity);


        final ArrayList<LayoutsDemoMainMenuItem> items = new ArrayList<>();

        LayoutsDemoMainMenuItem bridgeHeader = new LayoutsDemoMainMenuItem(getString(R.string.bridge_header), getString(R.string.bridge_header_description), null);
        items.add(bridgeHeader);

        LayoutsDemoMainMenuItem bridgeInScrollView = new LayoutsDemoMainMenuItem(getString(R.string.bridge_scroll_view), SFWebViewScrollViewActivity.class);
        items.add(bridgeInScrollView);

        LayoutsDemoMainMenuItem bridgeInRecyclerViewSmartFeed = new LayoutsDemoMainMenuItem(getString(R.string.bridge_recycler_view_smart_feed), SFWebViewRecyclerViewActivity.class);
        items.add(bridgeInRecyclerViewSmartFeed);

        LayoutsDemoMainMenuItem bridgeInRecyclerViewSmartLogic = new LayoutsDemoMainMenuItem(getString(R.string.bridge_recycler_view_smart_logic), SFWebViewRecyclerViewActivity.class, Pair.create("isSmartLogic", true));
        items.add(bridgeInRecyclerViewSmartLogic);

        LayoutsDemoMainMenuItem bridgeInRecyclerViewTwoWidgets = new LayoutsDemoMainMenuItem(getString(R.string.bridge_recycler_view_two_widgets), SFWebViewRecyclerViewActivity.class, Pair.create("twoWidgets", true));
        items.add(bridgeInRecyclerViewTwoWidgets);

        LayoutsDemoMainMenuItem classicHeader = new LayoutsDemoMainMenuItem(getString(R.string.article_header), getString(R.string.classic_header_description), null);
        items.add(classicHeader);

        LayoutsDemoMainMenuItem classicWithImages = new LayoutsDemoMainMenuItem(getString(R.string.classic_with_images), ClassicWithImageActivity.class);
        items.add(classicWithImages);

        LayoutsDemoMainMenuItem classicWithoutImages = new LayoutsDemoMainMenuItem(getString(R.string.classic_without_images), ClassicWithoutImageActivity.class);
        items.add(classicWithoutImages);

        LayoutsDemoMainMenuItem gridWithImages = new LayoutsDemoMainMenuItem(getString(R.string.grid_with_images), GridWithImagesActivity.class);
        items.add(gridWithImages);

        ListView listView = findViewById(R.id.outbrain_main_list_view);
        listView.setAdapter(new LayoutsDemoMainMenuAdapter(items));
        listView.setOnItemClickListener((adapterView, view, i, l) -> openActivity(items.get(i).openedActivityClass, items.get(i).extraData));
    }


    private void openActivity(Class cls, Pair<String, Boolean> extraData) {
        if (cls != null) {
            Intent intent = new Intent(this, cls);
            if (extraData != null) {
                intent.putExtra(extraData.first, extraData.second);
            }
            startActivity(intent);
        }
    }
}


class LayoutsDemoMainMenuItem {

    public String text;
    public String description;
    Class openedActivityClass;
    Pair<String, Boolean> extraData;


    LayoutsDemoMainMenuItem(String text, String description, Class openedActivityClass) {
        this.text = text;
        this.description = description;
        this.openedActivityClass = openedActivityClass;
    }


    LayoutsDemoMainMenuItem(String text, Class openedActivityClass) {
        this.text = text;
        this.openedActivityClass = openedActivityClass;
    }


    LayoutsDemoMainMenuItem(String text, Class openedActivityClass, Pair<String, Boolean> extraData) {
        this.text = text;
        this.openedActivityClass = openedActivityClass;
        this.extraData = extraData;
    }
}


class LayoutsDemoMainMenuAdapter extends BaseAdapter {

    private final ArrayList<LayoutsDemoMainMenuItem> items;


    public LayoutsDemoMainMenuAdapter(ArrayList<LayoutsDemoMainMenuItem> items) {
        super();
        this.items = items;
    }


    @Override
    public int getCount() {
        return items.size();
    }


    @Override
    public LayoutsDemoMainMenuItem getItem(int position) {
        return items.get(position);
    }


    @Override
    public long getItemId(int position) {
        return 0;
    }


    public int getItemViewType(int position) {
        return (position == 0 || position == 5) ? 0 : 1;
    }


    public int getViewTypeCount() {
        return 2;
    }


    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View returnView = convertView;
        TextView title;
        TextView desc;
        if (getItemViewType(position) == 0) {
            if (returnView == null) {
                returnView = LayoutInflater.from(parent.getContext()).inflate(R.layout.outbrain_layouts_main_menu_header_item, null);
            }
        } else {
            if (returnView == null) {
                returnView = LayoutInflater.from(parent.getContext()).inflate(R.layout.outbrain_layouts_main_menu_list_view_item, null);
            }
        }

        LayoutsDemoMainMenuItem item = getItem(position);
        title = returnView.findViewById(R.id.outbrain_layouts_main_menu_text_label);
        desc = returnView.findViewById(R.id.outbrain_layouts_main_menu_description_label);

        title.setText(item.text);
        if (desc != null) {
            desc.setText(item.description);
        }

        return returnView;
    }
}
