package com.outbrain.catalog.SFWebView;

import android.content.res.Configuration;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import com.outbrain.OBSDK.SFWebView.OutbrainBusProvider;
import com.outbrain.OBSDK.SFWebView.SFWebViewClickListener;
import com.outbrain.OBSDK.SFWebView.SFWebViewWidget;
import com.outbrain.catalog.R;


public class SFWebViewRecyclerViewActivity extends AppCompatActivity implements SwipeRefreshLayout.OnRefreshListener, SFWebViewClickListener {

    private final String LOG_TAG = "RecyclerViewActivity";
    private SwipeRefreshLayout mSwipeRefreshLayout;
    private SFWebViewWidget mSFRegularWidget;
    private SFWebViewWidget mSFSmartfeedWidget;
    private boolean twoWidgetsOnPage = false;
    private boolean isSmartLogic = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_sfwidget_recyclerview);
        OutbrainBusProvider.getInstance().register(this);

        this.mSwipeRefreshLayout = findViewById(R.id.swipe_container);
        mSwipeRefreshLayout.setOnRefreshListener(this);

        // use a linear layout manager
        RecyclerView.LayoutManager layoutManager = new LinearLayoutManager(this);
        RecyclerView recyclerView = findViewById(R.id.recycler_view);
        recyclerView.setLayoutManager(layoutManager);

        twoWidgetsOnPage = getIntent().getBooleanExtra("twoWidgets", false);
        isSmartLogic = getIntent().getBooleanExtra("isSmartLogic", false);

        if (twoWidgetsOnPage) {
            mSFRegularWidget = new SFWebViewWidget(
                    recyclerView,
                    "http://mobile-demo.outbrain.com",
                    "MB_2",
                    "NANOWDGT01"
            );
            mSFSmartfeedWidget = new SFWebViewWidget(
                    recyclerView,
                    "http://mobile-demo.outbrain.com",
                    "MB_1",
                    1,
                    "NANOWDGT01",
                    null,
                    false);

        } else {
            mSFSmartfeedWidget = new SFWebViewWidget(
                    recyclerView,
                    "http://mobile-demo.outbrain.com",
                    isSmartLogic ? "MB_3" : "MB_1",
                    0,
                    "NANOWDGT01",
                    null,
                    false);
        }

        SFWebViewExampleAdapter listAdapter = new SFWebViewExampleAdapter();
        if (twoWidgetsOnPage) {
            listAdapter.setSFRegularWidget(mSFRegularWidget);
        }

        listAdapter.setSFSmartfeedWidget(mSFSmartfeedWidget);
        recyclerView.setAdapter(listAdapter);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        OutbrainBusProvider.getInstance().unregister(this);
    }

    @Override
    public void onConfigurationChanged(@NonNull Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        if (twoWidgetsOnPage) {
            mSFRegularWidget.onActivityConfigurationChanged();
        }

        mSFSmartfeedWidget.onActivityConfigurationChanged();
    }

    @Override
    public void onRefresh() {
        final Handler handler = new Handler();
        handler.postDelayed(() -> {
            if (twoWidgetsOnPage) {
                mSFRegularWidget.reload();
            }

            mSFSmartfeedWidget.reload();
            mSwipeRefreshLayout.setRefreshing(false);
        }, 1000);
    }

    @Override
    public void onOrganicClick(String url) {
        // internal navigation in your app
        Log.i(LOG_TAG, "onOrganicClick: " + url);
    }
}
