package com.outbrain.catalog.SFWebView;

import android.content.res.Configuration;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.widget.ScrollView;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import com.outbrain.OBSDK.SFWebView.SFWebViewClickListener;
import com.outbrain.OBSDK.SFWebView.SFWebViewHeightDelegate;
import com.outbrain.OBSDK.SFWebView.SFWebViewWidget;
import com.outbrain.catalog.R;


public class SFWebViewScrollViewActivity extends AppCompatActivity implements SwipeRefreshLayout.OnRefreshListener, SFWebViewClickListener, SFWebViewHeightDelegate {

    private final String LOG_TAG = "SFWebViewScrollActivity";

    private SwipeRefreshLayout mSwipeRefreshLayout;
    private SFWebViewWidget mSFRegularWidget;
    private SFWebViewWidget mSFSmartfeedWidget;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_sfwidget_scrollview);

        this.mSwipeRefreshLayout = findViewById(R.id.swipe_container);
        mSwipeRefreshLayout.setOnRefreshListener(this);

        mSFRegularWidget = findViewById(R.id.sf_regular_widget);
        mSFSmartfeedWidget = findViewById(R.id.sf_smartfeed_widget);
        SFWebViewWidget.setHeightDelegateWeakReference(this);
        // uncomment if you want to handle clicks on organic urls
        // mSFWebViewWidget.setSfWebViewClickListener(this);

        final ScrollView scrollView = findViewById(R.id.scroll_view);
        SFWebViewWidget.setHeightDelegateWeakReference(new SFWebViewHeightDelegate() {
            @Override
            public int bottomPaddingForWidget(String widgetId) {
                if (widgetId.equals("MB_2")) {
                    return 0;
                }
                return 100;
            }
        });

        mSFSmartfeedWidget.setSfWebViewEventsListener((eventName, additionalData) -> {
            Log.i("ScrollViewActivity", "onWidgetEvent: " + eventName);
            Log.i("ScrollViewActivity", "onWidgetEvent: " + additionalData);
        });

        SFWebViewWidget.isWidgetEventsEnabled = true;
        mSFRegularWidget.init(scrollView, "http://mobile-demo.outbrain.com");
        mSFSmartfeedWidget.init(scrollView, "http://mobile-demo.outbrain.com");

    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (this.mSFSmartfeedWidget != null) {
            this.mSFSmartfeedWidget = null;
        }
        if (this.mSFRegularWidget != null) {
            this.mSFRegularWidget = null;
        }
    }

    @Override
    public void onConfigurationChanged(@NonNull Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        mSFRegularWidget.onActivityConfigurationChanged();
        mSFSmartfeedWidget.onActivityConfigurationChanged();
    }

    @Override
    public void onOrganicClick(String url) {
        // internal navigation in your app
        Log.i(LOG_TAG, "onOrganicClick: " + url);
    }

    @Override
    public void onRefresh() {
        final SFWebViewWidget sfRegularWidget = findViewById(R.id.sf_regular_widget);
        final SFWebViewWidget sfSmartfeedWidget = findViewById(R.id.sf_smartfeed_widget);

        final Handler handler = new Handler();
        handler.postDelayed(() -> {
            sfRegularWidget.reload();
            sfSmartfeedWidget.reload();
            mSwipeRefreshLayout.setRefreshing(false);
        }, 1000);
    }
}

